@@ -6,7 +6,8 @@ import types
 import re
 
 
-PY3 = sys.version_info >= (3,)
+NEEDS_OS_PATH_HACK = (
+    sys.platform == "win32" and (3, 12) <= sys.version_info < (3, 13))
 
 
 def contains_strict(seq, element):
@@ -34,6 +35,12 @@ def get_function_host(fn):
     try:
         name = fn.__name__
         obj = fn.__self__
+        if (
+            NEEDS_OS_PATH_HACK
+            and obj.__name__ == "nt"
+            and name.startswith('_path_')
+        ):
+            obj = None
     except AttributeError:
         pass
 
@@ -77,7 +84,7 @@ def find_invoking_frame_and_try_parse():
         if frame_info[3] in ('patch', 'spy2'):
             continue
 
-        source = ''.join(frame_info[4])
+        source = ''.join(frame_info[4] or [])
         m = FIND_ID.match(source)
         if m:
             # id should be something like `os.path.exists` etc.
