@@ -89,26 +89,18 @@ class Times(object):
                     if invoc.method_name == invocation.method_name
                 ]
                 or invocation.mock.invocations
-                or ['Nothing']
             )
+            wanted_section = (
+                "\nWanted but not invoked:\n\n    %s\n" % invocation
+            )
+            instead_section = (
+                "\nInstead got:\n\n    %s\n"
+                % "\n    ".join(map(str, invocations))
+            ) if invocations else ""
+
             raise VerificationError(
-                """
-Wanted but not invoked:
+                "%s%s\n" % (wanted_section, instead_section))
 
-    %s
-
-Instead got:
-
-    %s
-
-"""
-                % (
-                    invocation,
-                    "\n    ".join(
-                        str(invoc) for invoc in reversed(invocations)
-                    )
-                )
-            )
         else:
             if self.wanted_count == 0:
                 raise VerificationError(
@@ -131,13 +123,13 @@ class InOrder(object):
     def __init__(self, original_verification):
         '''
 
-        @param original_verification: Original verifiaction to degrade to if
+        @param original_verification: Original verification to degrade to if
                                       order of invocation was ok.
         '''
         self.original_verification = original_verification
 
     def verify(self, wanted_invocation, count):
-        for invocation in reversed(wanted_invocation.mock.invocations):
+        for invocation in wanted_invocation.mock.invocations:
             if not invocation.verified_inorder:
                 if not wanted_invocation.matches(invocation):
                     raise VerificationError(
